# FastAPI 👫👫 FastAPI ✔️ 🎆 👪 👈 🙋 👫👫 ⚪️➡️ 🌐 🖥. ## 👼 - 🐛 🙋 ❗ 👶 👉 👤: {% if people %}
{% for user in people.maintainers %}
@{{ user.login }}
❔: {{ user.answers }}
🚲 📨: {{ user.prs }}
{% endfor %}
{% endif %} 👤 👼 & 🐛 **FastAPI**. 👆 💪 ✍ 🌅 🔃 👈 [ℹ FastAPI - 🤚 ℹ - 🔗 ⏮️ 📕](help-fastapi.md#connect-with-the-author){.internal-link target=_blank}. ...✋️ 📥 👤 💚 🎦 👆 👪. --- **FastAPI** 📨 📚 🐕‍🦺 ⚪️➡️ 👪. & 👤 💚 🎦 👫 💰. 👫 👫👫 👈: * [ℹ 🎏 ⏮️ ❔ 📂](help-fastapi.md#help-others-with-questions-in-github){.internal-link target=_blank}. * [✍ 🚲 📨](help-fastapi.md#create-a-pull-request){.internal-link target=_blank}. * 📄 🚲 📨, [✴️ ⚠ ✍](contributing.md#translations){.internal-link target=_blank}. 👏 👫. 👶 👶 ## 🌅 🦁 👩‍💻 🏁 🗓️ 👫 👩‍💻 👈 ✔️ [🤝 🎏 🏆 ⏮️ ❔ 📂](help-fastapi.md#help-others-with-questions-in-github){.internal-link target=_blank} ⏮️ 🏁 🗓️. 👶 {% if people %}
{% for user in people.last_month_active %}
@{{ user.login }}
❔ 📨: {{ user.count }}
{% endfor %}
{% endif %} ## 🕴 📥 **FastAPI 🕴**. 👶 👫 👩‍💻 👈 ✔️ [ℹ 🎏 🏆 ⏮️ ❔ 📂](help-fastapi.md#help-others-with-questions-in-github){.internal-link target=_blank} 🔘 *🌐 🕰*. 👫 ✔️ 🎦 🕴 🤝 📚 🎏. 👶 {% if people %}
{% for user in people.experts %}
@{{ user.login }}
❔ 📨: {{ user.count }}
{% endfor %}
{% endif %} ## 🔝 👨‍🔬 📥 **🔝 👨‍🔬**. 👶 👉 👩‍💻 ✔️ [✍ 🏆 🚲 📨](help-fastapi.md#create-a-pull-request){.internal-link target=_blank} 👈 ✔️ *🔗*. 👫 ✔️ 📉 ℹ 📟, 🧾, ✍, ♒️. 👶 {% if people %}
{% for user in people.top_contributors %}
@{{ user.login }}
🚲 📨: {{ user.count }}
{% endfor %}
{% endif %} 📤 📚 🎏 👨‍🔬 (🌅 🌘 💯), 👆 💪 👀 👫 🌐 FastAPI 📂 👨‍🔬 📃. 👶 ## 🔝 👨‍🔬 👫 👩‍💻 **🔝 👨‍🔬**. 👶 👶 ### 📄 ✍ 👤 🕴 💬 👩‍❤‍👨 🇪🇸 (& 🚫 📶 👍 👶). , 👨‍🔬 🕐 👈 ✔️ [**🏋️ ✔ ✍**](contributing.md#translations){.internal-link target=_blank} 🧾. 🍵 👫, 📤 🚫🔜 🧾 📚 🎏 🇪🇸. --- **🔝 👨‍🔬** 👶 👶 ✔️ 📄 🏆 🚲 📨 ⚪️➡️ 🎏, 🚚 🔆 📟, 🧾, & ✴️, **✍**. {% if people %}
{% for user in people.top_reviewers %}
@{{ user.login }}
📄: {{ user.count }}
{% endfor %}
{% endif %} ## 💰 👫 **💰**. 👶 👫 🔗 👇 👷 ⏮️ **FastAPI** (& 🎏), ✴️ 🔘 📂 💰. {% if sponsors %} {% if sponsors.gold %} ### 🌟 💰 {% for sponsor in sponsors.gold -%} {% endfor %} {% endif %} {% if sponsors.silver %} ### 🥇1st 💰 {% for sponsor in sponsors.silver -%} {% endfor %} {% endif %} {% if sponsors.bronze %} ### 🥈2nd 💰 {% for sponsor in sponsors.bronze -%} {% endfor %} {% endif %} {% endif %} ### 🎯 💰 {% if github_sponsors %} {% for group in github_sponsors.sponsors %}
{% for user in group %} {% if user.login not in sponsors_badge.logins %}
@{{ user.login }}
{% endif %} {% endfor %}
{% endfor %} {% endif %} ## 🔃 📊 - 📡 ℹ 👑 🎯 👉 📃 🎦 🎯 👪 ℹ 🎏. ✴️ ✅ 🎯 👈 🛎 🌘 ⭐, & 📚 💼 🌅 😩, 💖 🤝 🎏 ⏮️ ❔ & ⚖ 🚲 📨 ⏮️ ✍. 💽 ⚖ 🔠 🗓️, 👆 💪 ✍ ℹ 📟 📥. 📥 👤 🎦 💰 ⚪️➡️ 💰. 👤 🏦 ▶️️ ℹ 📊, 📄, ⚡, ♒️ (💼 🤷).